@@ -5,59 +5,37 @@ import os
 import subprocess
 import sys
 
-import boto3
-import six
-
 from . import (
     RunwayModule, format_npm_command_for_logging, generate_node_command,
-    run_module_command, run_npm_install, warn_on_skipped_configs
+    run_module_command, run_npm_install, warn_on_boto_env_vars
+)
+from ..util import (
+    change_dir, run_commands, which
 )
-from ..util import change_dir, run_commands, which
 
 LOGGER = logging.getLogger('runway')
 
 
-def cdk_module_matches_env(env_name, env_config, env_vars):
-    """Return bool on whether cdk command should continue in current env."""
-    if env_config.get(env_name):
-        current_env_config = env_config[env_name]
-        if isinstance(current_env_config, type(True)) and current_env_config:
-            return True
-        if isinstance(current_env_config, six.string_types):
-            (account_id, region) = current_env_config.split('/')
-            if region == env_vars['AWS_DEFAULT_REGION']:
-                boto_args = {}
-                for i in ['aws_access_key_id', 'aws_secret_access_key',
-                          'aws_session_token']:
-                    if env_vars.get(i.upper()):
-                        boto_args[i] = env_vars[i.upper()]
-                sts_client = boto3.client(
-                    'sts',
-                    region_name=env_vars['AWS_DEFAULT_REGION'],
-                    **boto_args
-                )
-                if sts_client.get_caller_identity()['Account'] == account_id:
-                    return True
-    return False
-
-
-def get_cdk_stacks(module_path, env_vars):
+def get_cdk_stacks(module_path, env_vars, context_opts):
     """Return list of CDK stacks."""
     LOGGER.debug('Listing stacks in the CDK app prior to '
                  'diff')
-    return subprocess.check_output(
+    result = subprocess.check_output(
         generate_node_command(
             command='cdk',
-            command_opts=['list'],
+            command_opts=['list'] + context_opts,
             path=module_path),
         env=env_vars
-    ).strip().split('\n')
+    )
+    if isinstance(result, bytes):  # python3 returns encoded bytes
+        result = result.decode()
+    return result.strip().split('\n')
 
 
 class CloudDevelopmentKit(RunwayModule):
     """CDK Runway Module."""
 
-    def run_cdk(self, command='deploy'):
+    def run_cdk(self, command='deploy'):  # pylint: disable=too-many-branches
         """Run CDK."""
         response = {'skipped_configs': False}
         cdk_opts = [command]
@@ -70,9 +48,9 @@ class CloudDevelopmentKit(RunwayModule):
         if 'DEBUG' in self.context.env_vars:
             cdk_opts.append('-v')  # Increase logging if requested
 
-        if cdk_module_matches_env(self.context.env_name,
-                                  self.options.get('environments', {}),
-                                  self.context.env_vars):
+        warn_on_boto_env_vars(self.context.env_vars)
+
+        if self.options['environment']:
             if os.path.isfile(os.path.join(self.path, 'package.json')):
                 with change_dir(self.path):
                     run_npm_install(self.path, self.options, self.context)
@@ -87,12 +65,17 @@ class CloudDevelopmentKit(RunwayModule):
                             directory=self.path,
                             env=self.context.env_vars
                         )
+                    cdk_context_opts = []
+                    for (key, val) in self.options['parameters'].items():
+                        cdk_context_opts.extend(['-c', "%s=%s" % (key, val)])
+                    cdk_opts.extend(cdk_context_opts)
                     if command == 'diff':
                         LOGGER.info("Running cdk %s on each stack in %s",
                                     command,
                                     os.path.basename(self.path))
                         for i in get_cdk_stacks(self.path,
-                                                self.context.env_vars):
+                                                self.context.env_vars,
+                                                cdk_context_opts):
                             subprocess.call(
                                 generate_node_command(
                                     'cdk',
@@ -102,10 +85,17 @@ class CloudDevelopmentKit(RunwayModule):
                                 env=self.context.env_vars
                             )
                     else:
+                        # Make sure we're targeting all stacks
+                        if command in ['deploy', 'destroy']:
+                            cdk_opts.append('"*"')
+
                         if command == 'deploy':
+                            if 'CI' in self.context.env_vars:
+                                cdk_opts.append('--ci')
+                                cdk_opts.append('--require-approval=never')
                             bootstrap_command = generate_node_command(
                                 'cdk',
-                                ['bootstrap'],
+                                ['bootstrap'] + cdk_context_opts,
                                 self.path
                             )
                             LOGGER.info('Running cdk bootstrap...')
@@ -143,18 +133,12 @@ class CloudDevelopmentKit(RunwayModule):
 
     def plan(self):
         """Run cdk diff."""
-        result = self.run_cdk(command='diff')
-        warn_on_skipped_configs(result, self.context.env_name,
-                                self.context.env_vars)
+        self.run_cdk(command='diff')
 
     def deploy(self):
         """Run cdk deploy."""
-        result = self.run_cdk(command='deploy')
-        warn_on_skipped_configs(result, self.context.env_name,
-                                self.context.env_vars)
+        self.run_cdk(command='deploy')
 
     def destroy(self):
         """Run cdk destroy."""
-        result = self.run_cdk(command='destroy')
-        warn_on_skipped_configs(result, self.context.env_name,
-                                self.context.env_vars)
+        self.run_cdk(command='destroy')
